summaryrefslogtreecommitdiff
path: root/sw/inc/dbmgr.hxx
diff options
context:
space:
mode:
authorRüdiger Timm <rt@openoffice.org>2004-09-20 12:01:56 +0000
committerRüdiger Timm <rt@openoffice.org>2004-09-20 12:01:56 +0000
commit6d2af04bf21ac95e183fb06c862c290ef8caa5f6 (patch)
tree901b390c1e046b5af85ef48a458ad9b404c1ac45 /sw/inc/dbmgr.hxx
parent2e9d9dbf3b24e3726b01643dc894e3cbfe82ef24 (diff)
INTEGRATION: CWS swmailmerge (1.20.442); FILE MERGED
2004/09/15 13:32:44 os 1.20.442.8: RESYNC: (1.23-1.24); FILE MERGED 2004/08/17 06:20:44 os 1.20.442.7: #i25107# resync error corrected 2004/08/13 14:20:11 os 1.20.442.6: RESYNC: (1.22-1.23); FILE MERGED 2004/07/07 14:57:28 os 1.20.442.5: RESYNC: (1.21-1.22); FILE MERGED 2004/06/23 14:06:37 os 1.20.442.4: #i25107# weekly check-in 2004/05/28 20:24:19 os 1.20.442.3: RESYNC: (1.20-1.21); FILE MERGED 2004/05/28 12:27:31 os 1.20.442.2: #i25107# ChildWindow to return to the mail merge wizard 2004/05/14 13:57:56 os 1.20.442.1: #i25107# weekly check-in
Diffstat (limited to 'sw/inc/dbmgr.hxx')
-rw-r--r--sw/inc/dbmgr.hxx14
1 files changed, 11 insertions, 3 deletions
diff --git a/sw/inc/dbmgr.hxx b/sw/inc/dbmgr.hxx
index 7221a1d9b1b8..c508de26e2b1 100644
--- a/sw/inc/dbmgr.hxx
+++ b/sw/inc/dbmgr.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: dbmgr.hxx,v $
*
- * $Revision: 1.24 $
+ * $Revision: 1.25 $
*
- * last change: $Author: rt $ $Date: 2004-08-23 08:29:38 $
+ * last change: $Author: rt $ $Date: 2004-09-20 13:01:56 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -134,6 +134,7 @@ class SvNumberFormatter;
//CHINA001 class SwMailMergeDlg;
class SwDbtoolsClient;
class SwXMailMerge;
+class SwMailMergeConfigItem;
// -----------------------------------------------------------------------
@@ -143,7 +144,8 @@ enum DBMgrOptions
DBMGR_INSERT, // Datensaetze in Text
DBMGR_MERGE_MAILMERGE, // Serienbriefe drucken
DBMGR_MERGE_MAILING, // Serienbriefe als email versenden
- DBMGR_MERGE_MAILFILES // Serienbriefe als Datei(en) speichern
+ DBMGR_MERGE_MAILFILES, // Serienbriefe als Datei(en) speichern
+ DBMGR_MERGE_DOCUMENTS // Print merged documents
};
// -----------------------------------------------------------------------
@@ -269,6 +271,10 @@ public:
// Mischen von Datensaetzen in Felder, dann drucken
BOOL MergePrint( SwView& rView,
SwPrtOptions& rOpt, SfxProgress& rProgress );
+ // printing parts of a merge result document
+ BOOL MergePrintDocuments( SwView& rView,
+ SwPrtOptions& rOpt, SfxProgress& rProgress );
+
// Datenbankfelder mit fehlendem Datenbankname initialisieren
inline BOOL IsInitDBFields() const { return bInitDBFields; }
inline void SetInitDBFields(BOOL b) { bInitDBFields = b; }
@@ -413,6 +419,8 @@ public:
sal_Int32 _nCommandType,
const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XConnection>& _xConnection
);
+ //merge into one document - returns the number of merged docs
+ sal_Int32 MergeDocuments( SwMailMergeConfigItem& rMMConfig, SwView& rSourceView );
};
#endif